#
# spec file for package python-plumbum
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-plumbum
Version:        1.6.9
Release:        bp153.1.20
Summary:        Shell combinators library
License:        MIT
URL:            https://github.com/tomerfiliba/plumbum
Source:         https://github.com/tomerfiliba/plumbum/archive/v%{version}.tar.gz
Patch0:         no-python2.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module paramiko}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  openssh
BuildRequires:  sudo
# /SECTION
%python_subpackages

%description
Plumbum is a library for shell script-like programs in Python.

Apart from shell-like syntax and handy shortcuts, the library
provides local and remote command  execution (over SSH), local and
remote file-system paths, working-directory and environment
manipulation, and a programmatic Command-Line Interface (CLI)
application toolkit.

%prep
%setup -q -n plumbum-%{version}
%patch0 -p1
# remote tests won't work in OBS
rm tests/test_remote.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF8
# the skipped tests need running local SSH server or root privs
%pytest -k 'not (test_iterdir or test_iter_lines_timeout or test_iter_lines_error or test_atomic_file2 or test_pid_file or test_atomic_counter or test_as_user or test_copy_move_delete)'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Apr 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch fixing build with no python2 available:
  * no-python2.patch
- Update to 1.6.9:
  * Last version to support Python 2.6; added python_requires (#507)
  * Paths: Fix bug with subscription operations (#498), (#506)
  * Paths: Fix resolve (#492)
  * Commands: Fix resolve (#491)
  * Commands: Add context manager on popen (#495)
  * Several smaller fixes (#500), (#505)
* Wed Mar 18 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.6.8
  * Exceptions: Changed ProcessExecutionError's formatting to be more user-friendly
  * Commands: support for per-line timeout with iter_lines
  * Commands: support for piping stdout/stderr to a logger
  * Commands: execute local/remote commands via a magic .cmd attribute
  * Paths: support composing paths using subscription operations
  * CLI: Improved 'Set' validator to allow non-string types, and CSV params
  * TypedEnv: Facility for modeling environment-variables into python data types
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.6.7:
  * Commands: Added run_* methods as an alternative to modifiers (#386)
  * CLI: Added support for ALLOW_ABREV (#401)
  * CLI: Added DESCRIPTION_MORE, preserves spacing (#378)
  * Color: Avoid throwing error in atexit in special cases (like pytest) (#393)
  * Including Python 3.7 in testing matrix.
  * Smaller bugfixes and other testing improvements.
- Switch to github archive for tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Initial version
